==> REDCapR_1.0.0.tar.gz: REDCapR/inst/test-data/specific-redcapr/metadata-read/normal.R <==
structure(list(field_name = c("record_id", "name_first", "name_last", 
"address", "telephone", "email", "dob", "age", "sex", "height", 
"weight", "bmi", "comments", "mugshot", "race", "ethnicity", 
"interpreter_needed"), form_name = c("demographics", "demographics", 
"demographics", "demographics", "demographics", "demographics", 
"demographics", "demographics", "demographics", "health", "health", 
"health", "health", "health", "race_and_ethnicity", "race_and_ethnicity", 
"race_and_ethnicity"), section_header = c(NA, "Contact Information", 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "General Comments", NA, 
NA, NA, NA), field_type = c("text", "text", "text", "notes", 
"text", "text", "text", "text", "radio", "text", "text", "calc", 
"notes", "file", "checkbox", "radio", "truefalse"), field_label = c("Study ID", 
"First Name", "Last Name", "Street, City, State, ZIP", "Phone number", 
"E-mail", "Date of birth", "Age (years)", "Gender", "Height (cm)", 
"Weight (kilograms)", "BMI", "Comments", "Mugshot", "Race (Select all that apply)", 
"Ethnicity", "Are interpreter services requested?"), select_choices_or_calculations = c(NA, 
NA, NA, NA, NA, NA, NA, NA, "0, Female | 1, Male", NA, NA, "round(([weight]*10000)/(([height])^(2)),1)", 
NA, NA, "1, American Indian/Alaska Native | 2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 6, Unknown / Not Reported", 
"0, Unknown / Not Reported | 1, NOT Hispanic or Latino | 2, Hispanic or Latino", 
NA), field_note = c(NA, NA, NA, NA, "Include Area Code", NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA), text_validation_type_or_show_slider_number = c(NA, 
NA, NA, NA, "phone", "email", "date_ymd", NA, NA, "number", "integer", 
NA, NA, NA, NA, NA, NA), text_validation_min = c(NA, NA, NA, 
NA, NA, NA, NA, NA, NA, "130", "35", NA, NA, NA, NA, NA, NA), 
    text_validation_max = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    "215", "200", NA, NA, NA, NA, NA, NA), identifier = c(NA, 
    "y", "y", "y", "y", "y", "y", NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA), branching_logic = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_), required_field = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), custom_alignment = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_), question_number = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), matrix_group_name = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_), matrix_ranking = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), field_annotation = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_)), class = c("spec_tbl_df", 
"tbl_df", "tbl", "data.frame"), row.names = c(NA, -17L), spec = structure(list(
    cols = list(field_name = structure(list(), class = c("collector_character", 
    "collector")), form_name = structure(list(), class = c("collector_character", 
    "collector")), section_header = structure(list(), class = c("collector_character", 
    "collector")), field_type = structure(list(), class = c("collector_character", 
    "collector")), field_label = structure(list(), class = c("collector_character", 
    "collector")), select_choices_or_calculations = structure(list(), class = c("collector_character", 
    "collector")), field_note = structure(list(), class = c("collector_character", 
    "collector")), text_validation_type_or_show_slider_number = structure(list(), class = c("collector_character", 
    "collector")), text_validation_min = structure(list(), class = c("collector_character", 
    "collector")), text_validation_max = structure(list(), class = c("collector_character", 
    "collector")), identifier = structure(list(), class = c("collector_character", 
    "collector")), branching_logic = structure(list(), class = c("collector_character", 
    "collector")), required_field = structure(list(), class = c("collector_character", 
    "collector")), custom_alignment = structure(list(), class = c("collector_character", 
    "collector")), question_number = structure(list(), class = c("collector_character", 
    "collector")), matrix_group_name = structure(list(), class = c("collector_character", 
    "collector")), matrix_ranking = structure(list(), class = c("collector_character", 
    "collector")), field_annotation = structure(list(), class = c("collector_character", 
    "collector"))), default = structure(list(), class = c("collector_character", 
    "collector")), skip = 1), class = "col_spec"))

==> REDCapR_1.2.0.tar.gz: REDCapR/inst/test-data/specific-redcapr/metadata-read/normal.R <==
structure(list(field_name = c("record_id", "name_first", "name_last", 
"address", "telephone", "email", "dob", "age", "sex", "height", 
"weight", "bmi", "comments", "mugshot", "race", "ethnicity", 
"interpreter_needed"), form_name = c("demographics", "demographics", 
"demographics", "demographics", "demographics", "demographics", 
"demographics", "demographics", "demographics", "health", "health", 
"health", "health", "health", "race_and_ethnicity", "race_and_ethnicity", 
"race_and_ethnicity"), section_header = c(NA, "Contact Information", 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, "General Comments", NA, 
NA, NA, NA), field_type = c("text", "text", "text", "notes", 
"text", "text", "text", "text", "radio", "text", "text", "calc", 
"notes", "file", "checkbox", "radio", "truefalse"), field_label = c("Study ID", 
"First Name", "Last Name", "Street, City, State, ZIP", "Phone number", 
"E-mail", "Date of birth", "Age (years)", "Gender", "Height (cm)", 
"Weight (kilograms)", "BMI", "Comments", "Mugshot", "Race (Select all that apply)", 
"Ethnicity", "Are interpreter services requested?"), select_choices_or_calculations = c(NA, 
NA, NA, NA, NA, NA, NA, NA, "0, Female | 1, Male", NA, NA, "round(([weight]*10000)/(([height])^(2)),1)", 
NA, NA, "1, American Indian/Alaska Native | 2, Asian | 3, Native Hawaiian or Other Pacific Islander | 4, Black or African American | 5, White | 6, Unknown / Not Reported", 
"0, Unknown / Not Reported | 1, NOT Hispanic or Latino | 2, Hispanic or Latino", 
NA), field_note = c(NA, NA, NA, NA, "Include Area Code", NA, 
NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA), text_validation_type_or_show_slider_number = c(NA, 
NA, NA, NA, "phone", "email", "date_ymd", NA, NA, "number", "integer", 
NA, NA, NA, NA, NA, NA), text_validation_min = c(NA, NA, NA, 
NA, NA, NA, NA, NA, NA, "130", "35", NA, NA, NA, NA, NA, NA), 
    text_validation_max = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, 
    "215", "200", NA, NA, NA, NA, NA, NA), identifier = c(NA, 
    "y", "y", "y", "y", "y", "y", NA, NA, NA, NA, NA, NA, NA, 
    NA, NA, NA), branching_logic = c(NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_), required_field = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), custom_alignment = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_), question_number = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), matrix_group_name = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_), matrix_ranking = c(NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_
    ), field_annotation = c(NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_, NA_character_, NA_character_, 
    NA_character_, NA_character_)), row.names = c(NA, -17L), class = c("tbl_df", 
"tbl", "data.frame"))
